==> 1.0.2.tar.gz: bzb-2u/src/Printer.php <==
<?php

namespace smusatov\bzb2u;

class Printer
{
    private $resourcePrinter;

    public function __construct(string $device = '/dev/usb/lp')
    {
        if(!file_exists($device)) {
            throw new \Exception('The printer path does not exist');
        }

        if(!is_writable($device)) {
            throw new \Exception('The printer is not writable');
        }

        $this->resourcePrinter = fopen($device, 'w+b');

        if($this->resourcePrinter === false) {
            throw new \Exception('The printer could not be opened');
        }

        $this->setCharacterSets();
        $this->setSensorThrough();
        $this->setDarknessLevel();
        $this->setPrintSpeed();
        $this->setMicroMarginTop();
    }

    protected function setCharacterSets(int $n = 0): void
    {
        $n = max(0, min(9, $n));

        fprintf($this->resourcePrinter, '%c%s%u', 27, 'I', $n);
        usleep(100);
    }

    public function setSensorThrough(): void
    {
        fprintf($this->resourcePrinter, '%c%s', 27, 'F0');
        usleep(100);
    }

    public function setDarknessLevel(int $n = 5): void
    {
        $n = max(0, min(7, $n));

        fprintf($this->resourcePrinter, '%c%s%u', 27, 'D', $n);
        usleep(100);
    }

    public function setPrintSpeed(int $n = 1): void
    {
        $n = max(1, min(2, $n));

        fprintf($this->resourcePrinter, '%c%s%u', 27, 'S', $n);
        usleep(100);
    }

    protected function setMicroMarginTop(int $n = 0): void
    {
        $n = max(0, min(7, $n));

        fprintf($this->resourcePrinter, '%c%s%u', 27, 'a', $n);
        usleep(100);
    }

    public function setSensorReflect(): void
    {
        fprintf($this->resourcePrinter, '%c%s', 27, 'F1');
        usleep(100);
    }

    protected function setMarginLeft(int $marginLeft): void
    {
        fprintf($this->resourcePrinter, '%c%s%02u', 27, 'M', $marginLeft);
        usleep(100);
    }

    protected function setLabelLength(int $length): void
    {
//        $constQ = [22 => '032', 23 => '016', 24 => '004', 25 => '184', 26 => '176', 27 => '168', 28 => '160', 29 => '152', 30 => '144', 31 => '136', 32 => '128', 33 => '120', 34 => '112', 35 => '104', 36 => '096', 37 => '088', 38 => '080', 39 => '072', 40 => '064', 41 => '056', 42 => '048', 43 => '040', 44 => '032', 45 => '024', 46 => '016', 47 => '008', 48 => '004', 49 => '384'];
//        fprintf($this->resourcePrinter, '%c%s%s', 27, 'Q', $constQ[min($length, 49)]);

        fprintf($this->resourcePrinter, '%c%s%03u', 27, 'q', $length);
        usleep(100);
    }

    public function moveForward(int $mm): void
    {
        while($mm > 0) {
            fprintf($this->resourcePrinter, '%c%s%02u', 27, 'f', min($mm, 29));
            usleep(750);

            $mm -= 29;
        }
    }

    public function moveBack(int $mm): void
    {
        while($mm > 0) {
            fprintf($this->resourcePrinter, '%c%s%02u', 27, 'R', min($mm, 29));
            usleep(500);

            $mm -= 29;
        }
    }

    public function feedForm(): void
    {
        fprintf($this->resourcePrinter, '%c', 12);
        usleep(25000);
    }

    public function move(int $mm): void
    {
        if($mm > 0) {
            $this->moveForward($mm);
        } elseif($mm < 0) {
            $this->moveBack(abs($mm));
        }
    }

    protected function bufferOn(): void
    {
        fprintf($this->resourcePrinter, '%c%s', 27, 'B');
        usleep(100);
    }

    protected function bufferOff(): void
    {
        fprintf($this->resourcePrinter, '%c%s', 27, 'E');
        usleep(100);
    }

    protected function printBuffer(int $count): void
    {
        fprintf($this->resourcePrinter, '%c%s%02u', 27, 'P', $count);
        usleep(100);
    }

    public function execute(Job $job): void
    {
        $this->setMarginLeft(max(min(floor((56 - $job->getLabel()->getWidth()) / 2)-1, 28), 0));
        $this->setLabelLength($job->getLabel()->getHeight() + $job->getLabel()->getGap());

        $this->bufferOn();

        foreach($job->getLines() as $line) {

            $bytes = array_chunk($line, 8);

            $command = '';
            foreach($bytes as $byte) {
                $command .= chr(bindec(join('', $byte)));
            }

            fprintf($this->resourcePrinter, '%cG%02u%s', 27, count($bytes), $command);
            usleep(100);
        }

        $this->bufferOff();

        $this->printBuffer($job->getCount());
    }

}

==> 1.0.3.tar.gz: bzb-2u/src/Printer.php <==
<?php

namespace smusatov\bzb2u;

class Printer
{
    private $resourcePrinter;

    public function __construct(string $device = '/dev/usb/lp')
    {
        if(!file_exists($device)) {
            throw new \Exception('The printer path does not exist');
        }

        if(!is_writable($device)) {
            throw new \Exception('The printer is not writable');
        }

        $this->resourcePrinter = fopen($device, 'w+b');

        if($this->resourcePrinter === false) {
            throw new \Exception('The printer could not be opened');
        }

        $this->setCharacterSets();
        $this->setSensorThrough();
        $this->setDarknessLevel();
        $this->setPrintSpeed();
        $this->setMicroMarginTop();
    }

    protected function setCharacterSets(int $n = 0): void
    {
        $n = max(0, min(9, $n));

        fprintf($this->resourcePrinter, '%c%s%u', 27, 'I', $n);
        usleep(100);
    }

    public function setSensorThrough(): void
    {
        fprintf($this->resourcePrinter, '%c%s', 27, 'F0');
        usleep(100);
    }

    public function setDarknessLevel(int $n = 5): void
    {
        $n = max(0, min(7, $n));

        fprintf($this->resourcePrinter, '%c%s%u', 27, 'D', $n);
        usleep(100);
    }

    public function setPrintSpeed(int $n = 1): void
    {
        $n = max(1, min(2, $n));

        fprintf($this->resourcePrinter, '%c%s%u', 27, 'S', $n);
        usleep(100);
    }

    protected function setMicroMarginTop(int $n = 0): void
    {
        $n = max(0, min(7, $n));

        fprintf($this->resourcePrinter, '%c%s%u', 27, 'a', $n);
        usleep(100);
    }

    public function setSensorReflect(): void
    {
        fprintf($this->resourcePrinter, '%c%s', 27, 'F1');
        usleep(100);
    }

    protected function setMarginLeft(int $marginLeft): void
    {
        fprintf($this->resourcePrinter, '%c%s%02u', 27, 'M', $marginLeft);
        usleep(100);
    }

    protected function setLabelLength(int $length): void
    {
//        $constQ = [22 => '032', 23 => '016', 24 => '004', 25 => '184', 26 => '176', 27 => '168', 28 => '160', 29 => '152', 30 => '144', 31 => '136', 32 => '128', 33 => '120', 34 => '112', 35 => '104', 36 => '096', 37 => '088', 38 => '080', 39 => '072', 40 => '064', 41 => '056', 42 => '048', 43 => '040', 44 => '032', 45 => '024', 46 => '016', 47 => '008', 48 => '004', 49 => '384'];
//        fprintf($this->resourcePrinter, '%c%s%s', 27, 'Q', $constQ[min($length, 49)]);

        fprintf($this->resourcePrinter, '%c%s%03u', 27, 'q', $length);
        usleep(100);
    }

    public function moveForward(int $mm): void
    {
        while($mm > 0) {
            fprintf($this->resourcePrinter, '%c%s%02u', 27, 'f', min($mm, 29));
            usleep(750);

            $mm -= 29;
        }
    }

    public function moveBack(int $mm): void
    {
        while($mm > 0) {
            fprintf($this->resourcePrinter, '%c%s%02u', 27, 'R', min($mm, 29));
            usleep(500);

            $mm -= 29;
        }
    }

    public function feedForm(): void
    {
        fprintf($this->resourcePrinter, '%c', 12);
        usleep(25000);
    }

    public function move(int $mm): void
    {
        if($mm > 0) {
            $this->moveForward($mm);
        } elseif($mm < 0) {
            $this->moveBack(abs($mm));
        }
    }

    protected function bufferOn(): void
    {
        fprintf($this->resourcePrinter, '%c%s', 27, 'B');
        usleep(100);
    }

    protected function bufferOff(): void
    {
        fprintf($this->resourcePrinter, '%c%s', 27, 'E');
        usleep(100);
    }

    protected function printBuffer(int $count): void
    {
        fprintf($this->resourcePrinter, '%c%s%02u', 27, 'P', $count);
        usleep(100);
    }

    public function execute(Job $job): void
    {
        $this->setMarginLeft(max(min(floor((56 - $job->getLabel()->getWidth()) / 2), 28), 0));
        $this->setLabelLength($job->getLabel()->getHeight() + $job->getLabel()->getGap());

        $this->bufferOn();

        foreach($job->getLines() as $line) {

            $bytes = array_chunk($line, 8);

            $command = '';
            foreach($bytes as $byte) {
                $command .= chr(bindec(join('', $byte)));
            }

            fprintf($this->resourcePrinter, '%cG%02u%s', 27, count($bytes), $command);
            usleep(100);
        }

        $this->bufferOff();

        $this->printBuffer($job->getCount());
    }

}
